<?php
/**
 * @package     Room reservations
 * @subpackage  Room reservations component
 *
 * @author      Miloslav Schmied
 * @copyright   Copyright (C) 2016 - Ergotep, družstvo invalidů
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

use Joomla\Utilities\ArrayHelper;

// No direct access to this file
defined('_JEXEC') or die('Restricted access');

jimport('joomla.filesystem.file');

/**
 * Reservations Controller
 *
 * @since 1.0.0
 */
class JRoomBookingControllerReservations extends JControllerAdmin
{
    /**
     * Proxy for getModel.
     *
     * @param   string  $name    The model name. Optional.
     * @param   string  $prefix  The class prefix. Optional.
     * @param   array   $config  Configuration array for model. Optional.
     *
     * @return  object  The model.
     *
     * @since 1.0.0
     */
    public function getModel($name = 'ReservationAdmin', $prefix = 'JRoomBookingModel', $config = array('ignore_request' => true))
    {
        $model = parent::getModel($name, $prefix, $config);

        return $model;
    }

    /**
     * Prekryti publish metody predka. Slouzi pro schvalovani rezervaci.
     *
     * @since 1.0.0
     */

    public function publish()
    {
        // Check for request forgeries
        JSession::checkToken() or die(JText::_('JINVALID_TOKEN'));

        // Get items to publish from the request.
        $cid = JFactory::getApplication()->input->get('cid', array(), 'array');
        $data = array('publish' => 1, 'unpublish' => 0);
        $task = $this->getTask();
        $value = ArrayHelper::getValue($data, $task, 0, 'int');
        if (empty($cid))
        {
            JLog::add(JText::_($this->text_prefix . '_NO_ITEM_SELECTED'), JLog::WARNING, 'jerror');
        } else {
            // Get the model.
            $model = $this->getModel();

            // Make sure the item ids are integers
            ArrayHelper::toInteger($cid);

            try {
                $model->approve($cid, $value);
                $errors = $model->getErrors();
                if ($value == 1)
                {
                    $app = JFactory::getApplication();
                    if ($errors)
                    {

                        $app->enqueueMessage(JText::plural($this->text_prefix . '_N_ITEMS_FAILED_APPROVING', count($cid)), 'error');
                    }
                    else
                    {
                        $ntext = $this->text_prefix . '_N_ITEMS_APPROVED';
                        //odeslani emailu uzivateli
                        $send = $this->sendApprovalEmail($cid[count($cid)-1]);
                        if ($send === false) {
                            //chyba pri odesilani zpravy uzivateli
                            $app->enqueueMessage(JText::_('COM_JROOMBOOKING_RESERVATIONS_ERROR_SENDING_EMAIL'), 'error');
                        }
                    }
                }
                elseif ($value == 0)
                {
                    $ntext = $this->text_prefix . '_N_ITEMS_DISAPPROVED';
                }

                $this->setMessage(JText::plural($ntext, count($cid)));

            } catch (Exception $e) {
                $this->setMessage($e->getMessage(), 'error');
            }
        }

        $extension = $this->input->get('extension');
        $extensionURL = ($extension) ? '&extension=' . $extension : '';
        $this->setRedirect(JRoute::_('index.php?option=' . $this->option . '&view=' . $this->view_list . $extensionURL, false));
    }

  /**
   * Odesle email uzivateli s potvrzenim rezervace,
   */
    private function sendApprovalEmail($id) {
        $mailer = JFactory::getMailer();
        $model = $this->getModel('reservationadmin');
        $data = $model->getReservation($id);
        $params =  JComponentHelper::getParams('com_jroombooking');
        $config = JFactory::getConfig();
        $sender = array(
            $config->get( 'mailfrom' ),
            $config->get( 'fromname' )
        );
        // Nastavi typ zpravy na HTML
        $mailer->isHtml(true);
        $mailer->setSender($sender);
        $mailer->addRecipient($data->email);
        $mailer->setSubject($params->get('email_subject', 'Room reservations - Reservation approved'));

        $startDate = new JDate($data->start_date);
        $startDate = $startDate->format(JText::_('COM_JROOMBOOKING_RESERVATIONS_SHORT_DATE_FORMAT'));

        $endDate = new JDate($data->end_date);
        $endDate = $endDate->format(JText::_('COM_JROOMBOOKING_RESERVATIONS_SHORT_DATE_FORMAT'));

        $textColor = $params->get('email_text_color', '#ff6633');

        $logo = $params->get('email_logo');
        // pokud neni logo nastaveno, pouzije se vychozi
        $logoSrc = $logo === null ? 'https://www.jroombooking.com/images/logo.png' : (JURI::root() . 'images/' . $logo);

        $body  = '<div style="text-align: center">';
        $body .= '<a href="http://jroombooking.com"><img src="'.$logoSrc.'" style="width: 400px; height: auto; margin: 0 auto;"></a>';
        $body .= '<h1 style="margin: 50px 0;">' . $params->get('email_body', 'Your reservation has been approved.') . '</h1>';
        $body .= '<h2 style="line-height: 1;">Reservation information:</h2>';

//        $body  = '<div style="text-align: center">';
//        $body .= '<a href="http://jroombooking.com"><img src="'.$logoSrc.'" style="width: 400px; height: auto; margin: 0 auto;"></a>';
//        $body .= '<h1 style="margin: 50px 0;">' . $params->get('email_body', 'Your reservation has been approved.') . '</h1>';
//        $body .= '<h2 style="line-height: 1;">Reservation information:</h2>';

        $body .= '<p style="margin-bottom: 3px">' . $params->get('email_firstname', 'First name') . '</p>';
        $body .= '<p style="margin-top: 0; color: '.$textColor.'; font-size: 24px; font-weight: bold; line-height: 1;">' . $data->firstname . ' ' . $data->surname . '</p>';
        $body .= '<p style="margin-bottom: 3px">' . $params->get('email_term', 'Term of booking') . '</p>';
        $body .= '<p style="margin-top: 0; color: '.$textColor.'; font-size: 24px; font-weight: bold; line-height: 1;">' . $startDate . ' - ' . $endDate . '</p>';
        $body .= '<p style="margin-bottom: 3px">' . $params->get('email_room_name', 'Room name') . '</p>';
        $body .= '<p style="margin-top: 0; color: '.$textColor.'; font-size: 24px; font-weight: bold; line-height: 1;">' . $data->name . '</p>';
        $body .= '<p style="margin-bottom: 3px">' . $params->get('email_capacity', 'Number of beds') . '</p>';
        $body .= '<p style="margin-top: 0; color: '.$textColor.'; font-size: 24px; font-weight: bold; line-height: 1;">' . $data->capacity . '</p>';
        $body .= '</div>';

        $mailer->setBody($body);

        $send = $mailer->Send();
        return $send;
    }
}
