<?php
/**
 * @package     Room reservations
 * @subpackage  Room reservations component
 *
 * @author      Miloslav Schmied
 * @copyright   Copyright (C) 2016 - Ergotep, družstvo invalidů
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

// No direct access to this file
defined('_JEXEC') or die('Restricted access');

/**
 * JRoomBooking View
 *
 * @since  1.0.0
 */
class JRoomBookingViewJRoomBooking extends JViewLegacy
{
    protected $form;
    protected $item;
    protected $script;
    protected $canDo;

    /**
     * Display the JRoomBooking view
     *
     * @param string  $tpl  The name of the template file to parse; automatically searches through the template paths.
     *
     * @return void
     * @throws Exception error
     * @since 1.0.0
     */
    public function display($tpl = null)
    {
        // Get the Data
        $this->form = $this->get('Form');
        $this->item = $this->get('Item');
        $this->script = $this->get('Script');

        // What Access Permissions does this user have? What can (s)he do?
        $this->canDo = JRoomBookingHelper::getActions();

        // Check for errors.
        if (count($errors = $this->get('Errors')))
        {
            throw new Exception(implode("\n", $errors), 500);
        }


        // Set the toolbar
        $this->addToolBar();

        // Display the template
        parent::display($tpl);

        // Set the document
        $this->setDocument();
    }

    /**
     * Add the page title and toolbar.
     *
     * @return  void
     * @since   1.0.0
     */
    protected function addToolBar()
    {
        $input = JFactory::getApplication()->input;

        // Hide Joomla Administrator Main menu
        $input->set('hidemainmenu', true);

        $isNew = ($this->item->id == 0);

        if ($isNew)
        {
            $title = JText::_('COM_JROOMBOOKING_MANAGER_JROOMBOOKING_NEW');
            // For new records, check the create permission.
            if ($this->canDo->get('core.create'))
            {
                JToolBarHelper::apply('jroombooking.apply', 'JTOOLBAR_APPLY');
                JToolBarHelper::save('jroombooking.save', 'JTOOLBAR_SAVE');
                JToolBarHelper::custom('rooms.save2new', 'save-new.png', 'save-new_f2.png',
                    'JTOOLBAR_SAVE_AND_NEW', false);
            }
            JToolBarHelper::cancel('jroombooking.cancel', 'JTOOLBAR_CANCEL');
        }
        else
        {
            $title = JText::_('COM_JROOMBOOKING_MANAGER_JROOMBOOKING_EDIT');
            if ($this->canDo->get('core.edit'))
            {
                // We can save the new record
                JToolBarHelper::apply('jroombooking.apply', 'JTOOLBAR_APPLY');
                JToolBarHelper::save('jroombooking.save', 'JTOOLBAR_SAVE');

                // We can save this record, but check the create permission to see
                // if we can return to make a new one.
                if ($this->canDo->get('core.create'))
                {
                    JToolBarHelper::custom('jroombooking.save2new', 'save-new.png', 'save-new_f2.png',
                        'JTOOLBAR_SAVE_AND_NEW', false);
                }
            }
            if ($this->canDo->get('core.create'))
            {
                JToolBarHelper::custom('jroombooking.save2copy', 'save-copy.png', 'save-copy_f2.png',
                    'JTOOLBAR_SAVE_AS_COPY', false);
            }
            JToolBarHelper::cancel('jroombooking.cancel', 'JTOOLBAR_CLOSE');
        }

        JToolBarHelper::title($title, 'jroombooking');
    }

    /**
     * Method to set up the document properties
     *
     * @return void
     * @since 1.0.0
     */
    protected function setDocument()
    {
        $isNew = ($this->item->id == 0);
        $document = JFactory::getDocument();
        $document->setTitle($isNew ? JText::_('COM_JROOMBOOKING_JROOMBOOKING_CREATING') : JText::_('COM_JROOMBOOKING_JROOMBOOKING_EDITING'));
        $document->addScript(JURI::root() . $this->script);
        $document->addScript(JURI::root() . "/administrator/components/com_jroombooking" . "/views/jroombooking/submitbutton.js");
        JText::script('COM_JROOMBOOKING_JROOMBOOKING_ERROR_UNACCEPTABLE');
    }
}